Python Rubik Solver
===================

.. image:: https://badge.fury.io/py/rubik_solver.svg
   :target: https://badge.fury.io/py/rubik_solver

.. image:: https://landscape.io/github/Wiston999/python-rubik/master/landscape.svg?style=flat
   :target: https://landscape.io/github/Wiston999/python-rubik/master
   :alt: Code Health

.. image:: https://coveralls.io/repos/github/Wiston999/python-rubik/badge.svg?branch=master
   :target: https://coveralls.io/github/Wiston999/python-rubik?branch=master

.. image:: https://travis-ci.org/Wiston999/python-rubik.svg?branch=master
   :target: https://travis-ci.org/Wiston999/python-rubik

.. image:: https://readthedocs.org/projects/rubik-solver/badge/?version=latest
   :target: https://rubik-solver.readthedocs.io/en/latest/

Different algorithms and OpenGL representation of Rubik Cube

TODO
----
-  Improve documentation
-  Improve Kociemba Solver tests
